@@ -142,10 +142,11 @@ def generate_sector_report():
     
     N = 250
     for cat in ['消费','科技','宽基指数']:
-        fig = plt.figure(figsize = (20,60))
+        fig = plt.figure(figsize = (30,60))
         axes = []
-        axes.append(plt.subplot2grid((7,12),(0,0), colspan=5))
-        axes.append(plt.subplot2grid((7,12),(0,7), colspan=5))
+        axes.append(plt.subplot2grid((7,20),(0,0), colspan=5))
+        axes.append(plt.subplot2grid((7,20),(0,7), colspan=5))
+        axes.append(plt.subplot2grid((7,20),(0,14), colspan=5))
         
         ### 收益率
         df_plot = \
@@ -159,8 +160,9 @@ def generate_sector_report():
         customize_barh(df_plot,x_label='近5日收益率',y_label='指数名称',title='近5日收益率',ax=axes[1])
 
         for i in range(1,6):
-            axes.append(plt.subplot2grid((7,12),(i,0), colspan=5))
-            axes.append(plt.subplot2grid((7,12),(i,7), colspan=5))
+            axes.append(plt.subplot2grid((7,20),(i,0), colspan=5))
+            axes.append(plt.subplot2grid((7,20),(i,7), colspan=5))
+            axes.append(plt.subplot2grid((7,20),(i,14), colspan=5))
             
         i = 1
         for val_label in ['市盈率(ttm)','市净率','市销率(ttm)','股息率']:
@@ -171,7 +173,8 @@ def generate_sector_report():
 
             customize_barh(data=df_plot[['指数名称',val_label]].sort_values(val_label,ascending=False),
                            x_label = val_label, y_label = '指数名称',
-                           title = cat+': '+val_label+'(加权)', ax=axes[2*i])
+                           title = cat+': '+val_label+'(加权)',
+                           ax=axes[3*i])
 
             #### 当前估值在过去一年中的百分位
             df_plot = \
@@ -183,10 +186,27 @@ def generate_sector_report():
                            [['指数名称',val_label+'过去一年中百分位']]\
                            .sort_values(val_label+'过去一年中百分位',ascending=False),
                            x_label = val_label+'过去一年中百分位', y_label = '指数名称',
-                           title = cat+': '+val_label+'在过去一年中百分位', ax=axes[2*i+1])
-            axes[2*i+1].set_xlim((0,100))
+                           title = cat+': '+val_label+'在过去一年中百分位',
+                           ax=axes[3*i+1])
+            axes[3*i+1].set_xlim((0,100))
+            
+            #### 当前估值从2017年以来的百分位
+            df_plot = \
+            val[[val_label]].sort_index().unstack(level=[1,2,3])\
+            .apply(lambda x: rankdata(x)[-1] / np.sum(~pd.isna(x)) * 100)\
+            .to_frame(val_label+'从2017年以来的百分位')\
+            .reset_index()[['指数名称','类别',val_label+'从2017年以来的百分位']]
+
+            customize_barh(data=df_plot.query("""类别=='{}'""".format(cat))\
+                           [['指数名称',val_label+'从2017年以来的百分位']]\
+                           .sort_values(val_label+'从2017年以来的百分位',ascending=False),
+                           x_label = val_label+'从2017年以来的百分位', y_label = '指数名称',
+                           title = cat+': '+val_label+'从2017年以来的百分位',
+                           ax=axes[3*i+2])
+            axes[3*i+2].set_xlim((0,100))          
             i += 1
-        axes.append(plt.subplot2grid((7,12),(i,0), colspan=5, rowspan=2)) 
+        axes.append(plt.subplot2grid((7,20),(i,0), colspan=5, rowspan=2)) 
+        
         df_plot = \
         sector_roe.loc[sector_roe.类别 == cat].sort_values('ROE',ascending=False)[['指数名称','ROE','报告期']]
         customize_barh(data=df_plot, x_label = 'ROE', y_label = '指数名称', hue = '报告期',
@@ -194,7 +214,7 @@ def generate_sector_report():
                        ax = axes[-1])
             
         fig.suptitle('更新日期:' + max_dt, fontsize = 24, x = 0.5, y = 0.9 )
-        plt.savefig(cat+'.png', dpi=256)
+        plt.savefig(max_dt + '-估值与收益率-' + cat+'.png', dpi=256)
 
 def get_percent(data, label, N = 252*3, ax=None):
     percent = \
@@ -268,7 +288,7 @@ def est_trend(index_consensus, metric_names,
         #### 20日内变化 绝对差值
         data_diff = \
         index_consensus_day.set_index(['日期','指数名称'])[display_name].unstack()\
-        .sort_index().diff(periods = 20).mul(100).iloc[-1].sort_values(ascending=False)\
+        .sort_index().diff(periods = 20).iloc[-1].sort_values(ascending=False)\
         .to_frame(display_name).reset_index()
         customize_barh(data_diff, x_label = display_name,
                        y_label = '指数名称', title = display_name + '相较20个交易日前差值(%)',
